import { useCallback, useMemo } from 'react';
import { of } from 'rxjs';
import { map } from 'rxjs/operators';
import { useObservableState } from '@equinor/fusion-observable/react';
/**
 * Custom hook that provides access to the feature flags and their values.
 *
 * @param provider - The feature flag provider.
 * @param selector - Optional function to filter the feature flags.
 * @returns An object containing the features, any error that occurred while retrieving them, and a function to set the enabled state of a feature flag.
 * @throws Error if the feature flag provider is missing.
 */
export const useFeatures = (provider, selector) => {
    var _a;
    /**
     * Custom hook that provides access to the feature flags and their values.
     *
     * @returns An object containing the features and any error that occurred while retrieving them.
     */
    const { value: features, error } = useObservableState(useMemo(() => {
        if (provider) {
            return provider === null || provider === void 0 ? void 0 : provider.features$.pipe(map((x) => {
                const values = Object.values(x);
                return selector ? values.filter(selector) : values;
            }));
        }
        return of([]);
    }, [provider, selector]), { initial: Object.values((_a = provider === null || provider === void 0 ? void 0 : provider.features) !== null && _a !== void 0 ? _a : {}) });
    /**
     * Sets the enabled state of a feature flag.
     *
     * @param key - The key of the feature flag.
     * @param enable - The new enabled state of the feature flag.
     * @throws Error if IFeatureFlagProvider is missing.
     */
    const toggleFeature = useCallback((key, enable) => {
        var _a;
        if (!provider) {
            throw new Error('Missing IFeatureFlagProvider.');
        }
        const enabled = enable === undefined ? !((_a = provider.getFeature(key)) === null || _a === void 0 ? void 0 : _a.enabled) : enable;
        provider.toggleFeature({ key, enabled });
    }, [provider]);
    return { features, error, toggleFeature };
};
export default useFeatures;
//# sourceMappingURL=useFeatures.js.map